@@ -8,9 +8,10 @@ import pandas as pd
 from .structures import AddrMap, Pca
 from .structures import P, C, A
 
-__version__ = "0.1.4"
+__version__ = "0.1.8"
 
 pwd_path = os.path.abspath(os.path.dirname(__file__))
+# 区划地址文件
 pca_path = os.path.join(pwd_path, 'pca.csv')
 
 
@@ -45,32 +46,97 @@ def _data_from_csv() -> (AddrMap, AddrMap, AddrMap, dict, dict):
 def _fill_province_area_map(province_area_map: AddrMap, record_dict):
     pca_tuple = (record_dict['sheng'], record_dict['shi'], record_dict['qu'])
     key = (record_dict['sheng'], record_dict['qu'])
-    # 第三个参数在此处没有意义, 随便给的
+    # 第三个参数在此处没有意义
     province_area_map.append_relational_addr(key, pca_tuple, P)
 
 
+# 过滤混淆区名 '河北北戴河富丽小区1号'
+filter_area_names = ['河北区', '新城区']
+# 处理了部分常见自治县简写
+short_area_names = {
+    '白沙黎族自治县': '白沙县',
+    '昌江黎族自治县': '昌江县',
+    '乐东黎族自治县': '乐东县',
+    '陵水黎族自治县': '陵水县',
+    '保亭黎族苗族自治县': '保亭县',
+    '琼中黎族苗族自治县': '琼中县',
+    '长阳土家族自治县': '长阳县',
+    '五峰土家族自治县': '五峰县',
+    '大通回族土族自治县': '大通县',
+    '民和回族土族自治县': '民和县',
+    '互助土族自治县': '互助县',
+    '化隆回族自治县': '化隆县',
+    '循化撒拉族自治县': '循化县',
+    '青龙满族自治县': '青龙县',
+    '屏边苗族自治县': '屏边县',
+    '金平苗族瑶族傣族自治县': '金平县',
+    '河口瑶族自治县': '河口县',
+    '丰宁满族自治县': '丰宁县',
+    '宽城满族自治县': '宽城县',
+    '围场满族蒙古族自治县': '围场县',
+}
+
+
 def _fill_area_map(area_map: AddrMap, record_dict):
+    """
+    填充三级区划（区级）地名，包括简称
+    :param area_map: dict
+    :param record_dict: dict
+    :return: area_map
+    """
     area_name = record_dict['qu']
     pca_tuple = (record_dict['sheng'], record_dict['shi'], record_dict['qu'])
     area_map.append_relational_addr(area_name, pca_tuple, A)
-    if area_name.endswith('市'):
+    # 自治县区划简称
+    if area_name in short_area_names.keys():
+        area_map.append_relational_addr(short_area_names[area_name], pca_tuple, A)
+    # 4字区划简称
+    elif len(area_name) > 3 and (area_name.endswith('新区') or area_name.endswith('城区') or area_name.endswith('林区')):
+        area_map.append_relational_addr(area_name[:-2], pca_tuple, A)
+    # 过滤的区划名称
+    elif area_name in filter_area_names:
+        pass
+    # 3字区划简称，'XX区'不简写
+    elif len(area_name) > 2 and (area_name.endswith('市') or area_name.endswith('县')):
         area_map.append_relational_addr(area_name[:-1], pca_tuple, A)
 
 
+# 过滤混淆市名 eg '吉林省、吉林市的混淆'
+filter_city_names = ['吉林市']
+
+
 def _fill_city_map(city_map: AddrMap, record_dict):
+    """
+    填充二级区划（市级）地名，包括简称
+    :param city_map: dict
+    :param record_dict: dict
+    :return: city_map
+    """
     city_name = record_dict['shi']
     pca_tuple = (record_dict['sheng'], record_dict['shi'], record_dict['qu'])
     city_map.append_relational_addr(city_name, pca_tuple, C)
-    if city_name.endswith('市'):
+    # fix 吉林省、吉林市的混淆
+    if city_name in filter_city_names:
+        pass
+    elif city_name.endswith('市'):
         city_map.append_relational_addr(city_name[:-1], pca_tuple, C)
     # 特别行政区
     elif city_name == '香港特别行政区':
         city_map.append_relational_addr('香港', pca_tuple, C)
     elif city_name == '澳门特别行政区':
         city_map.append_relational_addr('澳门', pca_tuple, C)
+    # 自治区下的二级区划，eg喀什地区
+    elif len(city_name) > 3 and city_name.endswith('地区'):
+        city_map.append_relational_addr(city_name[:-2], pca_tuple, C)
 
 
 def _fill_province_map(province_map, record_dict):
+    """
+    填充一级区划（省级）地名，包括简称
+    :param province_map: dict
+    :param record_dict: dict
+    :return: province_map
+    """
     sheng = record_dict['sheng']
     if sheng not in province_map:
         province_map[sheng] = sheng
@@ -107,12 +173,14 @@ def is_munis(city_full_name):
     return city_full_name in munis
 
 
+# 区级到市级的映射
 myumap = {
     '南关区': '长春市',
     '南山区': '深圳市',
     '宝山区': '上海市',
-    '市辖区': '东莞市',
     '普陀区': '上海市',
+    '浦东区': '上海市',
+    '市辖区': '东莞市',
     '朝阳区': '北京市',
     '河东区': '天津市',
     '白云区': '广州市',
@@ -121,7 +189,7 @@ myumap = {
 }
 
 
-def transform(location_strs, umap=myumap, index=[], cut=True, lookahead=8, pos_sensitive=False, open_warning=True):
+def transform(location_strs, umap=myumap, index=[], cut=False, lookahead=8, pos_sensitive=False, open_warning=False):
     """将地址描述字符串转换以"省","市","区"信息为列的DataFrame表格
         Args:
             locations:地址描述字符集合,可以是list, Series等任意可以进行for in循环的集合
@@ -133,7 +201,7 @@ def transform(location_strs, umap=myumap, index=[], cut=True, lookahead=8, pos_s
                       默认值为8是为了能够发现"新疆维吾尔族自治区"这样的长地名
                       如果你的样本中都是短地名的话，可以考虑把这个数字调小一点以提高性能
             pos_sensitive:如果为True则会多返回三列，分别提取出的省市区在字符串中的位置，如果字符串中不存在的话则显示-1
-            open_warning: 是否打开umap警告, 默认打开
+            open_warning: 是否打开umap警告, 默认关闭
         Returns:
             一个Pandas的DataFrame类型的表格，如下：
                |省    |市   |区    |地址                 |
@@ -170,15 +238,14 @@ def _handle_one_record(addr, umap, cut, lookahead, pos_sensitive, open_warning):
         return empty
 
     # 地名提取
-    pca, addr = _extract_addr(addr, cut, lookahead)
-
+    pca, left_addr = _extract_addr(addr, cut, lookahead)
+    # 填充市
     _fill_city(pca, umap, open_warning)
-
+    # 填充省
     _fill_province(pca)
 
     result = pca.propertys_dict(pos_sensitive)
-    result["地址"] = addr
-
+    result["地址"] = left_addr
     return result
 
 
@@ -227,9 +294,7 @@ def _extract_addr(addr, cut, lookahead):
 def _jieba_extract(addr):
     """基于结巴分词进行提取"""
     import jieba
-
     result = Pca()
-
     pos = 0
     truncate = 0
 
@@ -258,11 +323,12 @@ def _jieba_extract(addr):
     return result, addr[truncate:]
 
 
+filter_address_chars = ['路', '街', '村', '桥']
+
+
 def _full_text_extract(addr, lookahead):
     """全文匹配进行提取"""
-
     result = Pca()
-
     truncate = 0
 
     def _set_pca(pca_property, pos, name, full_name):
@@ -288,11 +354,16 @@ def _full_text_extract(addr, lookahead):
         defer_fun = None
         # l为从起始位置开始的长度,从中提取出最长的地址
         for length in range(1, lookahead + 1):
-            if i + length > len(addr):
+            end_pos = i + length
+            if end_pos > len(addr):
                 break
-            word = addr[i:i + length]
+            word = addr[i:end_pos]
+            word_next = addr[end_pos] if end_pos < len(addr) else ''
+
             # 优先提取低级别的行政区 (主要是为直辖市和特别行政区考虑)
-            if word in area_map:
+            if word_next in filter_address_chars:
+                continue
+            elif word in area_map:
                 defer_fun = _set_pca('area', i, word, area_map.get_full_name(word))
                 continue
             elif word in city_map:
